@@ -76,12 +76,17 @@ class RetryBuildRequest(proto.Message):
     r"""Specifies a build to retry.
 
     Attributes:
+        name (str):
+            The name of the ``Build`` to retry. Format:
+            ``projects/{project}/locations/{location}/builds/{build}``
         project_id (str):
             Required. ID of the project.
         id (str):
             Required. Build ID of the original build.
     """
 
+    name = proto.Field(proto.STRING, number=3)
+
     project_id = proto.Field(proto.STRING, number=1)
 
     id = proto.Field(proto.STRING, number=2)
@@ -104,11 +109,7 @@ class RunBuildTriggerRequest(proto.Message):
 
     trigger_id = proto.Field(proto.STRING, number=2)
 
-    source = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message="RepoSource",
-    )
+    source = proto.Field(proto.MESSAGE, number=3, message="RepoSource",)
 
 
 class StorageSource(proto.Message):
@@ -120,7 +121,7 @@ class StorageSource(proto.Message):
             Google Cloud Storage bucket containing the source (see
             `Bucket Name
             Requirements <https://cloud.google.com/storage/docs/bucket-naming#requirements>`__).
-        object (str):
+        object_ (str):
             Google Cloud Storage object containing the source.
 
             This object must be a gzipped archive file (``.tar.gz``)
@@ -133,7 +134,7 @@ class StorageSource(proto.Message):
 
     bucket = proto.Field(proto.STRING, number=1)
 
-    object = proto.Field(proto.STRING, number=2)
+    object_ = proto.Field(proto.STRING, number=2)
 
     generation = proto.Field(proto.INT64, number=3)
 
@@ -161,7 +162,7 @@ class RepoSource(proto.Message):
             https://github.com/google/re2/wiki/Syntax
         commit_sha (str):
             Explicit commit SHA to build.
-        dir (str):
+        dir_ (str):
             Directory, relative to the source root, in which to run the
             build.
 
@@ -186,7 +187,7 @@ class RepoSource(proto.Message):
 
     commit_sha = proto.Field(proto.STRING, number=5, oneof="revision")
 
-    dir = proto.Field(proto.STRING, number=7)
+    dir_ = proto.Field(proto.STRING, number=7)
 
     invert_regex = proto.Field(proto.BOOL, number=8)
 
@@ -206,17 +207,11 @@ class Source(proto.Message):
     """
 
     storage_source = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        oneof="source",
-        message=StorageSource,
+        proto.MESSAGE, number=2, oneof="source", message="StorageSource",
     )
 
     repo_source = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        oneof="source",
-        message=RepoSource,
+        proto.MESSAGE, number=3, oneof="source", message="RepoSource",
     )
 
 
@@ -238,11 +233,7 @@ class BuiltImage(proto.Message):
 
     digest = proto.Field(proto.STRING, number=3)
 
-    push_timing = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        message="TimeSpan",
-    )
+    push_timing = proto.Field(proto.MESSAGE, number=4, message="TimeSpan",)
 
 
 class BuildStep(proto.Message):
@@ -283,7 +274,7 @@ class BuildStep(proto.Message):
             entrypoint. If the image does not define an entrypoint, the
             first element in args is used as the entrypoint, and the
             remainder will be used as arguments.
-        dir (str):
+        dir_ (str):
             Working directory to use when running this step's container.
 
             If this value is a relative path, it is relative to the
@@ -347,7 +338,7 @@ class BuildStep(proto.Message):
 
     args = proto.RepeatedField(proto.STRING, number=3)
 
-    dir = proto.Field(proto.STRING, number=4)
+    dir_ = proto.Field(proto.STRING, number=4)
 
     id = proto.Field(proto.STRING, number=5)
 
@@ -357,35 +348,15 @@ class BuildStep(proto.Message):
 
     secret_env = proto.RepeatedField(proto.STRING, number=8)
 
-    volumes = proto.RepeatedField(
-        proto.MESSAGE,
-        number=9,
-        message="Volume",
-    )
+    volumes = proto.RepeatedField(proto.MESSAGE, number=9, message="Volume",)
 
-    timing = proto.Field(
-        proto.MESSAGE,
-        number=10,
-        message="TimeSpan",
-    )
+    timing = proto.Field(proto.MESSAGE, number=10, message="TimeSpan",)
 
-    pull_timing = proto.Field(
-        proto.MESSAGE,
-        number=13,
-        message="TimeSpan",
-    )
+    pull_timing = proto.Field(proto.MESSAGE, number=13, message="TimeSpan",)
 
-    timeout = proto.Field(
-        proto.MESSAGE,
-        number=11,
-        message=duration.Duration,
-    )
+    timeout = proto.Field(proto.MESSAGE, number=11, message=duration.Duration,)
 
-    status = proto.Field(
-        proto.ENUM,
-        number=12,
-        enum="Build.Status",
-    )
+    status = proto.Field(proto.ENUM, number=12, enum="Build.Status",)
 
 
 class Volume(proto.Message):
@@ -441,11 +412,7 @@ class Results(proto.Message):
             Time to push all non-container artifacts.
     """
 
-    images = proto.RepeatedField(
-        proto.MESSAGE,
-        number=2,
-        message=BuiltImage,
-    )
+    images = proto.RepeatedField(proto.MESSAGE, number=2, message="BuiltImage",)
 
     build_step_images = proto.RepeatedField(proto.STRING, number=3)
 
@@ -455,11 +422,7 @@ class Results(proto.Message):
 
     build_step_outputs = proto.RepeatedField(proto.BYTES, number=6)
 
-    artifact_timing = proto.Field(
-        proto.MESSAGE,
-        number=7,
-        message="TimeSpan",
-    )
+    artifact_timing = proto.Field(proto.MESSAGE, number=7, message="TimeSpan",)
 
 
 class ArtifactResult(proto.Message):
@@ -477,11 +440,7 @@ class ArtifactResult(proto.Message):
 
     location = proto.Field(proto.STRING, number=1)
 
-    file_hash = proto.RepeatedField(
-        proto.MESSAGE,
-        number=2,
-        message="FileHashes",
-    )
+    file_hash = proto.RepeatedField(proto.MESSAGE, number=2, message="FileHashes",)
 
 
 class Build(proto.Message):
@@ -504,6 +463,11 @@ class Build(proto.Message):
     -  $SHORT_SHA: first 7 characters of $REVISION_ID or $COMMIT_SHA.
 
     Attributes:
+        name (str):
+            Output only. The 'Build' name with format:
+            ``projects/{project}/locations/{location}/builds/{build}``,
+            where {build} is a unique identifier generated by the
+            service.
         id (str):
             Output only. Unique identifier of the build.
         project_id (str):
@@ -538,6 +502,8 @@ class Build(proto.Message):
             the build will cease and the build status will be
             ``TIMEOUT``.
 
+            ``timeout`` starts ticking from ``startTime``.
+
             Default time is ten minutes.
         images (Sequence[str]):
             A list of images to be pushed upon the successful completion
@@ -596,6 +562,13 @@ class Build(proto.Message):
 
             If the build does not specify source or images, these keys
             will not be included.
+        service_account (str):
+            IAM service account whose credentials will be used at build
+            runtime. Must be of the format
+            ``projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}``. ACCOUNT
+            can be email address or uniqueId of the service account.
+
+            This field is in alpha and is not publicly available.
     """
 
     class Status(proto.Enum):
@@ -610,89 +583,45 @@ class Build(proto.Message):
         CANCELLED = 7
         EXPIRED = 9
 
+    name = proto.Field(proto.STRING, number=45)
+
     id = proto.Field(proto.STRING, number=1)
 
     project_id = proto.Field(proto.STRING, number=16)
 
-    status = proto.Field(
-        proto.ENUM,
-        number=2,
-        enum=Status,
-    )
+    status = proto.Field(proto.ENUM, number=2, enum=Status,)
 
     status_detail = proto.Field(proto.STRING, number=24)
 
-    source = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message=Source,
-    )
+    source = proto.Field(proto.MESSAGE, number=3, message="Source",)
 
-    steps = proto.RepeatedField(
-        proto.MESSAGE,
-        number=11,
-        message=BuildStep,
-    )
+    steps = proto.RepeatedField(proto.MESSAGE, number=11, message="BuildStep",)
 
-    results = proto.Field(
-        proto.MESSAGE,
-        number=10,
-        message=Results,
-    )
+    results = proto.Field(proto.MESSAGE, number=10, message="Results",)
 
-    create_time = proto.Field(
-        proto.MESSAGE,
-        number=6,
-        message=timestamp.Timestamp,
-    )
+    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp.Timestamp,)
 
-    start_time = proto.Field(
-        proto.MESSAGE,
-        number=7,
-        message=timestamp.Timestamp,
-    )
+    start_time = proto.Field(proto.MESSAGE, number=7, message=timestamp.Timestamp,)
 
-    finish_time = proto.Field(
-        proto.MESSAGE,
-        number=8,
-        message=timestamp.Timestamp,
-    )
+    finish_time = proto.Field(proto.MESSAGE, number=8, message=timestamp.Timestamp,)
 
-    timeout = proto.Field(
-        proto.MESSAGE,
-        number=12,
-        message=duration.Duration,
-    )
+    timeout = proto.Field(proto.MESSAGE, number=12, message=duration.Duration,)
 
     images = proto.RepeatedField(proto.STRING, number=13)
 
-    queue_ttl = proto.Field(
-        proto.MESSAGE,
-        number=40,
-        message=duration.Duration,
-    )
+    queue_ttl = proto.Field(proto.MESSAGE, number=40, message=duration.Duration,)
 
-    artifacts = proto.Field(
-        proto.MESSAGE,
-        number=37,
-        message="Artifacts",
-    )
+    artifacts = proto.Field(proto.MESSAGE, number=37, message="Artifacts",)
 
     logs_bucket = proto.Field(proto.STRING, number=19)
 
     source_provenance = proto.Field(
-        proto.MESSAGE,
-        number=21,
-        message="SourceProvenance",
+        proto.MESSAGE, number=21, message="SourceProvenance",
     )
 
     build_trigger_id = proto.Field(proto.STRING, number=22)
 
-    options = proto.Field(
-        proto.MESSAGE,
-        number=23,
-        message="BuildOptions",
-    )
+    options = proto.Field(proto.MESSAGE, number=23, message="BuildOptions",)
 
     log_url = proto.Field(proto.STRING, number=25)
 
@@ -700,18 +629,11 @@ class Build(proto.Message):
 
     tags = proto.RepeatedField(proto.STRING, number=31)
 
-    secrets = proto.RepeatedField(
-        proto.MESSAGE,
-        number=32,
-        message="Secret",
-    )
+    secrets = proto.RepeatedField(proto.MESSAGE, number=32, message="Secret",)
 
-    timing = proto.MapField(
-        proto.STRING,
-        proto.MESSAGE,
-        number=33,
-        message="TimeSpan",
-    )
+    timing = proto.MapField(proto.STRING, proto.MESSAGE, number=33, message="TimeSpan",)
+
+    service_account = proto.Field(proto.STRING, number=42)
 
 
 class Artifacts(proto.Message):
@@ -771,19 +693,11 @@ class Artifacts(proto.Message):
 
         paths = proto.RepeatedField(proto.STRING, number=2)
 
-        timing = proto.Field(
-            proto.MESSAGE,
-            number=3,
-            message="TimeSpan",
-        )
+        timing = proto.Field(proto.MESSAGE, number=3, message="TimeSpan",)
 
     images = proto.RepeatedField(proto.STRING, number=1)
 
-    objects = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=ArtifactObjects,
-    )
+    objects = proto.Field(proto.MESSAGE, number=2, message=ArtifactObjects,)
 
 
 class TimeSpan(proto.Message):
@@ -796,17 +710,9 @@ class TimeSpan(proto.Message):
             End of time span.
     """
 
-    start_time = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message=timestamp.Timestamp,
-    )
+    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
 
-    end_time = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=timestamp.Timestamp,
-    )
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
 
 
 class BuildOperationMetadata(proto.Message):
@@ -817,11 +723,7 @@ class BuildOperationMetadata(proto.Message):
             The build that the operation is tracking.
     """
 
-    build = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message=Build,
-    )
+    build = proto.Field(proto.MESSAGE, number=1, message="Build",)
 
 
 class SourceProvenance(proto.Message):
@@ -851,22 +753,13 @@ class SourceProvenance(proto.Message):
     """
 
     resolved_storage_source = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message=StorageSource,
+        proto.MESSAGE, number=3, message="StorageSource",
     )
 
-    resolved_repo_source = proto.Field(
-        proto.MESSAGE,
-        number=6,
-        message=RepoSource,
-    )
+    resolved_repo_source = proto.Field(proto.MESSAGE, number=6, message="RepoSource",)
 
     file_hashes = proto.MapField(
-        proto.STRING,
-        proto.MESSAGE,
-        number=4,
-        message="FileHashes",
+        proto.STRING, proto.MESSAGE, number=4, message="FileHashes",
     )
 
 
@@ -880,18 +773,14 @@ class FileHashes(proto.Message):
             Collection of file hashes.
     """
 
-    file_hash = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message="Hash",
-    )
+    file_hash = proto.RepeatedField(proto.MESSAGE, number=1, message="Hash",)
 
 
 class Hash(proto.Message):
     r"""Container message for hash values.
 
     Attributes:
-        type (~.cloudbuild.Hash.HashType):
+        type_ (~.cloudbuild.Hash.HashType):
             The type of hash that was performed.
         value (bytes):
             The hash value.
@@ -903,11 +792,7 @@ class Hash(proto.Message):
         SHA256 = 1
         MD5 = 2
 
-    type = proto.Field(
-        proto.ENUM,
-        number=1,
-        enum=HashType,
-    )
+    type_ = proto.Field(proto.ENUM, number=1, enum=HashType,)
 
     value = proto.Field(proto.BYTES, number=2)
 
@@ -940,31 +825,37 @@ class CreateBuildRequest(proto.Message):
     r"""Request to create a new build.
 
     Attributes:
+        parent (str):
+            The parent resource where this build will be created.
+            Format: ``projects/{project}/locations/{location}``
         project_id (str):
             Required. ID of the project.
         build (~.cloudbuild.Build):
             Required. Build resource to create.
     """
 
+    parent = proto.Field(proto.STRING, number=4)
+
     project_id = proto.Field(proto.STRING, number=1)
 
-    build = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=Build,
-    )
+    build = proto.Field(proto.MESSAGE, number=2, message="Build",)
 
 
 class GetBuildRequest(proto.Message):
     r"""Request to get a build.
 
     Attributes:
+        name (str):
+            The name of the ``Build`` to retrieve. Format:
+            ``projects/{project}/locations/{location}/builds/{build}``
         project_id (str):
             Required. ID of the project.
         id (str):
             Required. ID of the build.
     """
 
+    name = proto.Field(proto.STRING, number=4)
+
     project_id = proto.Field(proto.STRING, number=1)
 
     id = proto.Field(proto.STRING, number=2)
@@ -974,6 +865,9 @@ class ListBuildsRequest(proto.Message):
     r"""Request to list builds.
 
     Attributes:
+        parent (str):
+            The parent of the collection of ``Builds``. Format:
+            ``projects/{project}/locations/location``
         project_id (str):
             Required. ID of the project.
         page_size (int):
@@ -985,6 +879,8 @@ class ListBuildsRequest(proto.Message):
             The raw filter text to constrain the results.
     """
 
+    parent = proto.Field(proto.STRING, number=9)
+
     project_id = proto.Field(proto.STRING, number=1)
 
     page_size = proto.Field(proto.INT32, number=2)
@@ -1008,11 +904,7 @@ class ListBuildsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    builds = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=Build,
-    )
+    builds = proto.RepeatedField(proto.MESSAGE, number=1, message="Build",)
 
     next_page_token = proto.Field(proto.STRING, number=2)
 
@@ -1021,12 +913,17 @@ class CancelBuildRequest(proto.Message):
     r"""Request to cancel an ongoing build.
 
     Attributes:
+        name (str):
+            The name of the ``Build`` to retrieve. Format:
+            ``projects/{project}/locations/{location}/builds/{build}``
         project_id (str):
             Required. ID of the project.
         id (str):
             Required. ID of the build.
     """
 
+    name = proto.Field(proto.STRING, number=4)
+
     project_id = proto.Field(proto.STRING, number=1)
 
     id = proto.Field(proto.STRING, number=2)
@@ -1075,12 +972,11 @@ class BuildTrigger(proto.Message):
             Output only. Time when the trigger was
             created.
         disabled (bool):
-            If true, the trigger will never result in a
-            build.
+            If true, the trigger will never automatically
+            execute a build.
         substitutions (Sequence[~.cloudbuild.BuildTrigger.SubstitutionsEntry]):
             Substitutions for Build resource. The keys must match the
-            following regular expression: ``^_[A-Z0-9_]+$``.The keys
-            cannot conflict with the keys in bindings.
+            following regular expression: ``^_[A-Z0-9_]+$``.
         ignored_files (Sequence[str]):
             ignored_files and included_files are file glob matches using
             https://golang.org/pkg/path/filepath/#Match extended with
@@ -1113,32 +1009,17 @@ class BuildTrigger(proto.Message):
 
     tags = proto.RepeatedField(proto.STRING, number=19)
 
-    trigger_template = proto.Field(
-        proto.MESSAGE,
-        number=7,
-        message=RepoSource,
-    )
+    trigger_template = proto.Field(proto.MESSAGE, number=7, message="RepoSource",)
 
-    github = proto.Field(
-        proto.MESSAGE,
-        number=13,
-        message="GitHubEventsConfig",
-    )
+    github = proto.Field(proto.MESSAGE, number=13, message="GitHubEventsConfig",)
 
     build = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="build_template",
-        message=Build,
+        proto.MESSAGE, number=4, oneof="build_template", message="Build",
     )
 
     filename = proto.Field(proto.STRING, number=8, oneof="build_template")
 
-    create_time = proto.Field(
-        proto.MESSAGE,
-        number=5,
-        message=timestamp.Timestamp,
-    )
+    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp.Timestamp,)
 
     disabled = proto.Field(proto.BOOL, number=9)
 
@@ -1182,18 +1063,10 @@ class GitHubEventsConfig(proto.Message):
     name = proto.Field(proto.STRING, number=7)
 
     pull_request = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="event",
-        message="PullRequestFilter",
+        proto.MESSAGE, number=4, oneof="event", message="PullRequestFilter",
     )
 
-    push = proto.Field(
-        proto.MESSAGE,
-        number=5,
-        oneof="event",
-        message="PushFilter",
-    )
+    push = proto.Field(proto.MESSAGE, number=5, oneof="event", message="PushFilter",)
 
 
 class PullRequestFilter(proto.Message):
@@ -1207,8 +1080,8 @@ class PullRequestFilter(proto.Message):
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
         comment_control (~.cloudbuild.PullRequestFilter.CommentControl):
-            Whether to block builds on a "/gcbrun"
-            comment from a repository admin or collaborator.
+            Configure builds to run whether a repository owner or
+            collaborator need to comment ``/gcbrun``.
         invert_regex (bool):
             If true, branches that do NOT match the git_ref will trigger
             a build.
@@ -1221,11 +1094,7 @@ class PullRequestFilter(proto.Message):
 
     branch = proto.Field(proto.STRING, number=2, oneof="git_ref")
 
-    comment_control = proto.Field(
-        proto.ENUM,
-        number=5,
-        enum=CommentControl,
-    )
+    comment_control = proto.Field(proto.ENUM, number=5, enum=CommentControl,)
 
     invert_regex = proto.Field(proto.BOOL, number=6)
 
@@ -1270,11 +1139,7 @@ class CreateBuildTriggerRequest(proto.Message):
 
     project_id = proto.Field(proto.STRING, number=1)
 
-    trigger = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=BuildTrigger,
-    )
+    trigger = proto.Field(proto.MESSAGE, number=2, message="BuildTrigger",)
 
 
 class GetBuildTriggerRequest(proto.Message):
@@ -1330,11 +1195,7 @@ class ListBuildTriggersResponse(proto.Message):
     def raw_page(self):
         return self
 
-    triggers = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=BuildTrigger,
-    )
+    triggers = proto.RepeatedField(proto.MESSAGE, number=1, message="BuildTrigger",)
 
     next_page_token = proto.Field(proto.STRING, number=2)
 
@@ -1372,11 +1233,7 @@ class UpdateBuildTriggerRequest(proto.Message):
 
     trigger_id = proto.Field(proto.STRING, number=2)
 
-    trigger = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message=BuildTrigger,
-    )
+    trigger = proto.Field(proto.MESSAGE, number=3, message="BuildTrigger",)
 
 
 class BuildOptions(proto.Message):
@@ -1400,19 +1257,29 @@ class BuildOptions(proto.Message):
             builds that request more than the maximum are rejected with
             an error.
         substitution_option (~.cloudbuild.BuildOptions.SubstitutionOption):
-            Option to specify behavior when there is an
-            error in the substitution checks.
+            Option to specify behavior when there is an error in the
+            substitution checks.
+
+            NOTE: this is always set to ALLOW_LOOSE for triggered builds
+            and cannot be overridden in the build configuration file.
+        dynamic_substitutions (bool):
+            Option to specify whether or not to apply
+            bash style string operations to the
+            substitutions.
+            NOTE: this is always enabled for triggered
+            builds and cannot be overridden in the build
+            configuration file.
         log_streaming_option (~.cloudbuild.BuildOptions.LogStreamingOption):
             Option to define build log streaming behavior
             to Google Cloud Storage.
         worker_pool (str):
             Option to specify a ``WorkerPool`` for the build. Format:
-            projects/{project}/workerPools/{workerPool}
+            projects/{project}/locations/{location}/workerPools/{workerPool}
 
             This field is experimental.
         logging (~.cloudbuild.BuildOptions.LoggingMode):
             Option to specify the logging mode, which
-            determines where the logs are stored.
+            determines if and where build logs are stored.
         env (Sequence[str]):
             A list of global environment variable
             definitions that will exist for all build steps
@@ -1450,7 +1317,10 @@ class BuildOptions(proto.Message):
         VERIFIED = 1
 
     class MachineType(proto.Enum):
-        r"""Supported VM sizes."""
+        r"""Supported Compute Engine machine types. For more information, see
+        `Machine
+        types <https://cloud.google.com/compute/docs/machine-types>`__.
+        """
         UNSPECIFIED = 0
         N1_HIGHCPU_8 = 1
         N1_HIGHCPU_32 = 2
@@ -1475,56 +1345,35 @@ class BuildOptions(proto.Message):
         LOGGING_UNSPECIFIED = 0
         LEGACY = 1
         GCS_ONLY = 2
+        STACKDRIVER_ONLY = 3
+        CLOUD_LOGGING_ONLY = 5
+        NONE = 4
 
     source_provenance_hash = proto.RepeatedField(
-        proto.ENUM,
-        number=1,
-        enum=Hash.HashType,
+        proto.ENUM, number=1, enum="Hash.HashType",
     )
 
-    requested_verify_option = proto.Field(
-        proto.ENUM,
-        number=2,
-        enum=VerifyOption,
-    )
+    requested_verify_option = proto.Field(proto.ENUM, number=2, enum=VerifyOption,)
 
-    machine_type = proto.Field(
-        proto.ENUM,
-        number=3,
-        enum=MachineType,
-    )
+    machine_type = proto.Field(proto.ENUM, number=3, enum=MachineType,)
 
     disk_size_gb = proto.Field(proto.INT64, number=6)
 
-    substitution_option = proto.Field(
-        proto.ENUM,
-        number=4,
-        enum=SubstitutionOption,
-    )
+    substitution_option = proto.Field(proto.ENUM, number=4, enum=SubstitutionOption,)
 
-    log_streaming_option = proto.Field(
-        proto.ENUM,
-        number=5,
-        enum=LogStreamingOption,
-    )
+    dynamic_substitutions = proto.Field(proto.BOOL, number=17)
+
+    log_streaming_option = proto.Field(proto.ENUM, number=5, enum=LogStreamingOption,)
 
     worker_pool = proto.Field(proto.STRING, number=7)
 
-    logging = proto.Field(
-        proto.ENUM,
-        number=11,
-        enum=LoggingMode,
-    )
+    logging = proto.Field(proto.ENUM, number=11, enum=LoggingMode,)
 
     env = proto.RepeatedField(proto.STRING, number=12)
 
     secret_env = proto.RepeatedField(proto.STRING, number=13)
 
-    volumes = proto.RepeatedField(
-        proto.MESSAGE,
-        number=14,
-        message=Volume,
-    )
+    volumes = proto.RepeatedField(proto.MESSAGE, number=14, message="Volume",)
 
 
 class WorkerPool(proto.Message):
@@ -1596,41 +1445,17 @@ class WorkerPool(proto.Message):
 
     worker_count = proto.Field(proto.INT64, number=4)
 
-    worker_config = proto.Field(
-        proto.MESSAGE,
-        number=16,
-        message="WorkerConfig",
-    )
+    worker_config = proto.Field(proto.MESSAGE, number=16, message="WorkerConfig",)
 
-    regions = proto.RepeatedField(
-        proto.ENUM,
-        number=9,
-        enum=Region,
-    )
+    regions = proto.RepeatedField(proto.ENUM, number=9, enum=Region,)
 
-    create_time = proto.Field(
-        proto.MESSAGE,
-        number=11,
-        message=timestamp.Timestamp,
-    )
+    create_time = proto.Field(proto.MESSAGE, number=11, message=timestamp.Timestamp,)
 
-    update_time = proto.Field(
-        proto.MESSAGE,
-        number=17,
-        message=timestamp.Timestamp,
-    )
+    update_time = proto.Field(proto.MESSAGE, number=17, message=timestamp.Timestamp,)
 
-    delete_time = proto.Field(
-        proto.MESSAGE,
-        number=12,
-        message=timestamp.Timestamp,
-    )
+    delete_time = proto.Field(proto.MESSAGE, number=12, message=timestamp.Timestamp,)
 
-    status = proto.Field(
-        proto.ENUM,
-        number=13,
-        enum=Status,
-    )
+    status = proto.Field(proto.ENUM, number=13, enum=Status,)
 
 
 class WorkerConfig(proto.Message):
@@ -1671,11 +1496,7 @@ class WorkerConfig(proto.Message):
 
     disk_size_gb = proto.Field(proto.INT64, number=2)
 
-    network = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message="Network",
-    )
+    network = proto.Field(proto.MESSAGE, number=3, message="Network",)
 
     tag = proto.Field(proto.STRING, number=4)
 
@@ -1718,11 +1539,7 @@ class CreateWorkerPoolRequest(proto.Message):
 
     parent = proto.Field(proto.STRING, number=1)
 
-    worker_pool = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=WorkerPool,
-    )
+    worker_pool = proto.Field(proto.MESSAGE, number=2, message="WorkerPool",)
 
 
 class GetWorkerPoolRequest(proto.Message):
@@ -1765,11 +1582,7 @@ class UpdateWorkerPoolRequest(proto.Message):
 
     name = proto.Field(proto.STRING, number=2)
 
-    worker_pool = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message=WorkerPool,
-    )
+    worker_pool = proto.Field(proto.MESSAGE, number=3, message="WorkerPool",)
 
 
 class ListWorkerPoolsRequest(proto.Message):
@@ -1791,11 +1604,7 @@ class ListWorkerPoolsResponse(proto.Message):
             ``WorkerPools`` for the project.
     """
 
-    worker_pools = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=WorkerPool,
-    )
+    worker_pools = proto.RepeatedField(proto.MESSAGE, number=1, message="WorkerPool",)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
